==> haskell-text-ansi-0.3.0-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-ansi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-ansi
version:              0.3.0
visibility:           public
id:                   text-ansi-0.3.0-ZCmCOxRm7X8tuN0ZfrIKn
key:                  text-ansi-0.3.0-ZCmCOxRm7X8tuN0ZfrIKn
license:              BSD-3-Clause
copyright:            (c) 2018-2023, Mitchell Rosen
maintainer:           Mitchell Rosen <mitchellwrosen@gmail.com>
author:               Mitchell Rosen
homepage:             https://github.com/mitchellwrosen/text-ansi
synopsis:             Text styling for ANSI terminals.
description:
    Text styling for ANSI terminals using SGR codes, as defined by the
    <https://www.ecma-international.org/publications/files/ECMA-ST/Ecma-048.pdf ECMA-48>
    standard.

    Supports foreground\/background color, bold\/faint intensity, italic,
    single\/double underline, strikethrough, frame, encircle, and overline escape
    sequences. Some styles may not work on your terminal.

    Also features terminal detection, so redirecting styled output to a file will
    automatically strip the ANSI escape sequences.

category:             Data
abi:                  c947e2ce7e326c57707875f6e0d2345a
exposed:              True
exposed-modules:
    String.ANSI Text.ANSI Text.Builder.ANSI Text.Lazy.Builder.ANSI

import-dirs:          /usr/lib/ghc-9.4.8/site-local/text-ansi-0.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/text-ansi-0.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/text-ansi-0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-ansi
hs-libraries:         HStext-ansi-0.3.0-ZCmCOxRm7X8tuN0ZfrIKn
depends:
    base-4.17.2.1 text-2.0.2
    text-builder-linear-0.1.3-8CjmjbrOS3c8daajf7CLWB

haddock-interfaces:   /usr/share/doc/haskell-text-ansi/html/text-ansi.haddock
haddock-html:         /usr/share/doc/haskell-text-ansi/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-ansi-0.3.0-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-ansi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-ansi
version:              0.3.0
visibility:           public
id:                   text-ansi-0.3.0-ESrGSxeMuOjRLYUlEiwYv
key:                  text-ansi-0.3.0-ESrGSxeMuOjRLYUlEiwYv
license:              BSD-3-Clause
copyright:            (c) 2018-2023, Mitchell Rosen
maintainer:           Mitchell Rosen <mitchellwrosen@gmail.com>
author:               Mitchell Rosen
homepage:             https://github.com/mitchellwrosen/text-ansi
synopsis:             Text styling for ANSI terminals.
description:
    Text styling for ANSI terminals using SGR codes, as defined by the
    <https://www.ecma-international.org/publications/files/ECMA-ST/Ecma-048.pdf ECMA-48>
    standard.

    Supports foreground\/background color, bold\/faint intensity, italic,
    single\/double underline, strikethrough, frame, encircle, and overline escape
    sequences. Some styles may not work on your terminal.

    Also features terminal detection, so redirecting styled output to a file will
    automatically strip the ANSI escape sequences.

category:             Data
abi:                  d55a6a4c52db2621237532a0aed44d8f
exposed:              True
exposed-modules:
    String.ANSI Text.ANSI Text.Builder.ANSI Text.Lazy.Builder.ANSI

import-dirs:          /usr/lib/ghc-9.4.8/site-local/text-ansi-0.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/text-ansi-0.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/text-ansi-0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-ansi
hs-libraries:         HStext-ansi-0.3.0-ESrGSxeMuOjRLYUlEiwYv
depends:
    base-4.17.2.1 text-2.0.2
    text-builder-linear-0.1.3-NBhMMC0nzzCbeCFAqVLS8

haddock-interfaces:   /usr/share/doc/haskell-text-ansi/html/text-ansi.haddock
haddock-html:         /usr/share/doc/haskell-text-ansi/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
